@@ -1,6 +1,6 @@
 def load(h):
-    return ({'abbr': 1, 'code': 1, 'title': 'First-order spatial differencing'},
-            {'abbr': 2, 'code': 2, 'title': 'Second-order spatial differencing'},
+    return ({'abbr': 0, 'code': 0, 'title': 'No clutter filter used'},
+            {'abbr': 1, 'code': 1, 'title': 'Clutter filter used'},
             {'abbr': 192, 'code': 192, 'title': 'Reserved for local use'},
             {'abbr': 193, 'code': 193, 'title': 'Reserved for local use'},
             {'abbr': 194, 'code': 194, 'title': 'Reserved for local use'},
